# Mesh Adaptive Direct Search (MADS)
This package provides an implementation of the Mesh Adaptive Direct Search (MADS) algorithm for gradient-free optimization [1]. More specifically, it uses a modified variant of MADS with orthogonal search directions (OrthoMADS) [2]. However, it abandons using the deterministic Halton sequence for search directions in favor of random search directions, and only performs poll steps.

### Using MADS
The user must provide the following arguments
 - A numpy array of initial design variables
 - A numpy array of upper bounds for the design variables
 - A numpy array of lower bounds for the design variables
 - An objective function to be minimized
 - A stopping tolerance based on the poll size e.g. 1E-6
 - A stopping tolerance based on the objective function e.g. 1E-6
 - A stopping tolerance based on the maximum number of iterations
 - A True/False flag for printing optimization statistics

MADS will perform up to the specified maximum number of design iterations. At each iteration it will perform up to 2N evaluations of the objective function, where N is the number of design variables, skipping points that have already been evaluated. It automatically shrinks/expands the poll size to search the design space, and exits when any one of the three aforementioned stopping criteria is met.

Upon completion, MADS returns
 - The mimimized value of the objective function
 - A numpy array of the design variables that yielded this minima

### Example Applications


### References
[1] C. Audet and J. E. Dennis, Mesh Adaptive Direct Search Algorithms for Constrained Optimization, SIAM Journal on Optimization, 2006, 17 (1), 188-217.
[2] M. A. Abramson, C. Audet, J. E. Dennis, and S. Le Digabel, OrthoMADS: A Deterministic MADS Instance with Orthogonal Directions, SIAM Journal on Optimization, 2009, 20 (2), 948-966.